You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2011/01/15 13:03:42 UTC

svn commit: r1059307 [4/5] - in /incubator/river/jtsk/skunk/modules: river-libs/river-dl/src/main/java/net/jini/discovery/ river-libs/river-dl/src/main/java/net/jini/lookup/entry/ river-libs/river-dl/src/main/java/org/apache/river/admin/ river-libs/riv...

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Client.java Sat Jan 15 12:03:35 2011
@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.internal;
+package org.apache.river.discovery.internal;
 
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastAnnouncementDecoder;
-import com.sun.jini.discovery.DiscoveryProtocolException;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.MulticastRequestEncoder;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastAnnouncementDecoder;
+import org.apache.river.discovery.DiscoveryProtocolException;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.MulticastRequestEncoder;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.logging.Level;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Constraints.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Constraints.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Constraints.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Constraints.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.internal;
+package org.apache.river.discovery.internal;
 
 import java.util.Arrays;
 import java.util.ArrayList;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Provider.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Provider.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Server.java Sat Jan 15 12:03:35 2011
@@ -16,15 +16,15 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.internal;
+package org.apache.river.discovery.internal;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastRequestDecoder;
-import com.sun.jini.discovery.DiscoveryProtocolException;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastAnnouncementEncoder;
-import com.sun.jini.discovery.MulticastRequest;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastRequestDecoder;
+import org.apache.river.discovery.DiscoveryProtocolException;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastAnnouncementEncoder;
+import org.apache.river.discovery.MulticastRequest;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.security.cert.Certificate;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Client.java Sat Jan 15 12:03:35 2011
@@ -16,13 +16,13 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.kerberos;
+package org.apache.river.discovery.kerberos;
 
-import com.sun.jini.discovery.UnicastDiscoveryClient;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.EndpointBasedClient;
-import com.sun.jini.discovery.internal.EndpointInternals;
-import com.sun.jini.discovery.internal.KerberosEndpointInternalsAccess;
+import org.apache.river.discovery.UnicastDiscoveryClient;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.EndpointBasedClient;
+import org.apache.river.discovery.internal.EndpointInternals;
+import org.apache.river.discovery.internal.KerberosEndpointInternalsAccess;
 import java.io.IOException;
 import java.net.Socket;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/Server.java Sat Jan 15 12:03:35 2011
@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.kerberos;
+package org.apache.river.discovery.kerberos;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.UnicastDiscoveryServer;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.EndpointBasedServer;
-import com.sun.jini.discovery.internal.EndpointInternals;
-import com.sun.jini.discovery.internal.KerberosEndpointInternalsAccess;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.UnicastDiscoveryServer;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.EndpointBasedServer;
+import org.apache.river.discovery.internal.EndpointInternals;
+import org.apache.river.discovery.internal.KerberosEndpointInternalsAccess;
 import java.io.IOException;
 import java.net.Socket;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/kerberos/package.html Sat Jan 15 12:03:35 2011
@@ -25,15 +25,15 @@
 
 Provides an implementation of the <code>net.jini.discovery.kerberos</code>
 discovery format, specified in the <i>Jini Discovery and Join
-Specification</i>.  The {@link com.sun.jini.discovery.kerberos.Client} class
+Specification</i>.  The {@link org.apache.river.discovery.kerberos.Client} class
 implements the client side of the <code>net.jini.discovery.kerberos</code>
 discovery format for the unicast discovery protocol, while the {@link
-com.sun.jini.discovery.kerberos.Server} class implements the server side of the
+org.apache.river.discovery.kerberos.Server} class implements the server side of the
 discovery format for that protocol.  Both classes are intended to be specified
 in a resource to configure the operation of the
-{@link com.sun.jini.discovery.Discovery} class, as described in the
+{@link org.apache.river.discovery.Discovery} class, as described in the
 documentation for
-{@link com.sun.jini.discovery.Discovery#getProtocol2(ClassLoader)}.
+{@link org.apache.river.discovery.Discovery#getProtocol2(ClassLoader)}.
 
 <h2>Supported Constraints</h2>
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/package.html Sat Jan 15 12:03:35 2011
@@ -27,32 +27,32 @@ Provides a set of constraints, low-level
 interfaces for participating in versions 1 and 2 of the multicast request,
 multicast announcement, and unicast discovery protocols.
 <p>
-The {@link com.sun.jini.discovery.DiscoveryProtocolVersion},
-{@link com.sun.jini.discovery.MulticastMaxPacketSize},
-{@link com.sun.jini.discovery.MulticastTimeToLive} and
-{@link com.sun.jini.discovery.UnicastSocketTimeout} classes represent
+The {@link org.apache.river.discovery.DiscoveryProtocolVersion},
+{@link org.apache.river.discovery.MulticastMaxPacketSize},
+{@link org.apache.river.discovery.MulticastTimeToLive} and
+{@link org.apache.river.discovery.UnicastSocketTimeout} classes represent
 constraints which can be applied to multicast and unicast discovery.  The
-{@link com.sun.jini.discovery.DiscoveryConstraints} class offers convenience
+{@link org.apache.river.discovery.DiscoveryConstraints} class offers convenience
 methods for querying the values expressed by groups of these constraints.  The
-{@link com.sun.jini.discovery.Discovery} class provides methods implementing
+{@link org.apache.river.discovery.Discovery} class provides methods implementing
 various low-level discovery protocol operations, such as encoding and decoding
 multicast packet contents and unicast discovery data.  These methods accept as
-arguments instances of the {@link com.sun.jini.discovery.MulticastRequest},
-{@link com.sun.jini.discovery.MulticastAnnouncement} and
-{@link com.sun.jini.discovery.UnicastResponse} classes, which represent the
+arguments instances of the {@link org.apache.river.discovery.MulticastRequest},
+{@link org.apache.river.discovery.MulticastAnnouncement} and
+{@link org.apache.river.discovery.UnicastResponse} classes, which represent the
 values (independent of protocol details) to be transmitted by multicast
 requests, multicast announcements, and unicast discovery.
 <p>
 The <code>Discovery</code> class implements both versions 1 and 2 of the
 discovery protocols.  For version 2 of the protocols, it accepts pluggable
 format providers, specified via resource using the
-{@link com.sun.jini.discovery.DiscoveryFormatProvider} interface, which
-implement the {@link com.sun.jini.discovery.MulticastRequestEncoder},
-{@link com.sun.jini.discovery.MulticastRequestDecoder},
-{@link com.sun.jini.discovery.MulticastAnnouncementEncoder},
-{@link com.sun.jini.discovery.MulticastAnnouncementDecoder},
-{@link com.sun.jini.discovery.UnicastDiscoveryClient}, and
-{@link com.sun.jini.discovery.UnicastDiscoveryServer} format provider
+{@link org.apache.river.discovery.DiscoveryFormatProvider} interface, which
+implement the {@link org.apache.river.discovery.MulticastRequestEncoder},
+{@link org.apache.river.discovery.MulticastRequestDecoder},
+{@link org.apache.river.discovery.MulticastAnnouncementEncoder},
+{@link org.apache.river.discovery.MulticastAnnouncementDecoder},
+{@link org.apache.river.discovery.UnicastDiscoveryClient}, and
+{@link org.apache.river.discovery.UnicastDiscoveryServer} format provider
 sub-interfaces.
 
 @see "<i>Jini Discovery and Join Specification</i>"

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Client.java Sat Jan 15 12:03:35 2011
@@ -16,16 +16,16 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.plaintext;
+package org.apache.river.discovery.plaintext;
 
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastAnnouncementDecoder;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.MulticastRequestEncoder;
-import com.sun.jini.discovery.UnicastDiscoveryClient;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.Plaintext;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastAnnouncementDecoder;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.MulticastRequestEncoder;
+import org.apache.river.discovery.UnicastDiscoveryClient;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.Plaintext;
 import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.net.Socket;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/Server.java Sat Jan 15 12:03:35 2011
@@ -16,17 +16,17 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.plaintext;
+package org.apache.river.discovery.plaintext;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastAnnouncementEncoder;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.MulticastRequestDecoder;
-import com.sun.jini.discovery.UnicastDiscoveryServer;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.Plaintext;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastAnnouncementEncoder;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.MulticastRequestDecoder;
+import org.apache.river.discovery.UnicastDiscoveryServer;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.Plaintext;
 import java.io.BufferedOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/plaintext/package.html Sat Jan 15 12:03:35 2011
@@ -25,15 +25,15 @@
 
 Provides an implementation of the <code>net.jini.discovery.plaintext</code>
 discovery format, specified in the <i>Jini Discovery and Join
-Specification</i>.  The {@link com.sun.jini.discovery.plaintext.Client} class
+Specification</i>.  The {@link org.apache.river.discovery.plaintext.Client} class
 implements the client side of the <code>net.jini.discovery.plaintext</code>
 discovery format for the multicast request, multicast announcement, and unicast
-discovery protocols, while the {@link com.sun.jini.discovery.plaintext.Server}
+discovery protocols, while the {@link org.apache.river.discovery.plaintext.Server}
 class implements the server side of the discovery format for those protocols.
 Both classes are intended to be specified in a resource to configure the
-operation of the {@link com.sun.jini.discovery.Discovery} class, as described
+operation of the {@link org.apache.river.discovery.Discovery} class, as described
 in the documentation for
-{@link com.sun.jini.discovery.Discovery#getProtocol2(ClassLoader)}.
+{@link org.apache.river.discovery.Discovery#getProtocol2(ClassLoader)}.
 
 <h2>Supported Constraints</h2>
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Client.java Sat Jan 15 12:03:35 2011
@@ -16,13 +16,13 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.ssl;
+package org.apache.river.discovery.ssl;
 
-import com.sun.jini.discovery.UnicastDiscoveryClient;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.EndpointBasedClient;
-import com.sun.jini.discovery.internal.EndpointInternals;
-import com.sun.jini.discovery.internal.SslEndpointInternalsAccess;
+import org.apache.river.discovery.UnicastDiscoveryClient;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.EndpointBasedClient;
+import org.apache.river.discovery.internal.EndpointInternals;
+import org.apache.river.discovery.internal.SslEndpointInternalsAccess;
 import java.io.IOException;
 import java.net.Socket;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/Server.java Sat Jan 15 12:03:35 2011
@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.ssl;
+package org.apache.river.discovery.ssl;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.UnicastDiscoveryServer;
-import com.sun.jini.discovery.UnicastResponse;
-import com.sun.jini.discovery.internal.EndpointBasedServer;
-import com.sun.jini.discovery.internal.EndpointInternals;
-import com.sun.jini.discovery.internal.SslEndpointInternalsAccess;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.UnicastDiscoveryServer;
+import org.apache.river.discovery.UnicastResponse;
+import org.apache.river.discovery.internal.EndpointBasedServer;
+import org.apache.river.discovery.internal.EndpointInternals;
+import org.apache.river.discovery.internal.SslEndpointInternalsAccess;
 import java.io.IOException;
 import java.net.Socket;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/ssl/package.html Sat Jan 15 12:03:35 2011
@@ -25,14 +25,14 @@
 
 Provides an implementation of the <code>net.jini.discovery.ssl</code> discovery
 format, specified in the <i>Jini Discovery and Join Specification</i>.  The
-{@link com.sun.jini.discovery.ssl.Client} class implements the client side of
+{@link org.apache.river.discovery.ssl.Client} class implements the client side of
 the <code>net.jini.discovery.ssl</code> discovery format for the unicast
-discovery protocol, while the {@link com.sun.jini.discovery.ssl.Server} class
+discovery protocol, while the {@link org.apache.river.discovery.ssl.Server} class
 implements the server side of the discovery format for that protocol.  Both
 classes are intended to be specified in a resource to configure the operation
-of the {@link com.sun.jini.discovery.Discovery} class, as described in the
+of the {@link org.apache.river.discovery.Discovery} class, as described in the
 documentation for
-{@link com.sun.jini.discovery.Discovery#getProtocol2(ClassLoader)}.
+{@link org.apache.river.discovery.Discovery#getProtocol2(ClassLoader)}.
 
 <h2>Supported Constraints</h2>
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Client.java Sat Jan 15 12:03:35 2011
@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withdsa;
+package org.apache.river.discovery.x500.sha1withdsa;
 
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastAnnouncementDecoder;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.MulticastRequestEncoder;
-import com.sun.jini.discovery.internal.X500Client;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastAnnouncementDecoder;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.MulticastRequestEncoder;
+import org.apache.river.discovery.internal.X500Client;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import net.jini.core.constraint.InvocationConstraints;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Constants.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Constants.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Constants.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Constants.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withdsa;
+package org.apache.river.discovery.x500.sha1withdsa;
 
 /**
  * Constants used by net.jini.discovery.x500.SHA1withDSA format providers.

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/Server.java Sat Jan 15 12:03:35 2011
@@ -16,15 +16,15 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withdsa;
+package org.apache.river.discovery.x500.sha1withdsa;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastRequestDecoder;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastAnnouncementEncoder;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.internal.X500Server;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastRequestDecoder;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastAnnouncementEncoder;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.internal.X500Server;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import net.jini.core.constraint.InvocationConstraints;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withdsa/package.html Sat Jan 15 12:03:35 2011
@@ -26,14 +26,14 @@
 Provides an implementation of the
 <code>net.jini.discovery.x500.SHA1withDSA</code> discovery format, specified in
 the <i>Jini Discovery and Join Specification</i>.  The {@link
-com.sun.jini.discovery.x500.sha1withdsa.Client} class implements the client
+org.apache.river.discovery.x500.sha1withdsa.Client} class implements the client
 side of the <code>net.jini.discovery.x500.SHA1withDSA</code> discovery format
 for the multicast request and multicast announcement discovery protocols, while
-the {@link com.sun.jini.discovery.x500.sha1withdsa.Server} class implements the
+the {@link org.apache.river.discovery.x500.sha1withdsa.Server} class implements the
 server side of the discovery format for those protocols.  Both classes are
 intended to be specified in a resource to configure the operation of the {@link
-com.sun.jini.discovery.Discovery} class, as described in the documentation for
-{@link com.sun.jini.discovery.Discovery#getProtocol2(ClassLoader)}.
+org.apache.river.discovery.Discovery} class, as described in the documentation for
+{@link org.apache.river.discovery.Discovery#getProtocol2(ClassLoader)}.
 
 <h2>Supported Constraints</h2>
 
@@ -106,7 +106,7 @@ Both <code>Client</code> and <code>Serve
 of the following system properties:
 <p>
 <dl>
-  <dt> <code>com.sun.jini.discovery.x500.trustStore</code>
+  <dt> <code>org.apache.river.discovery.x500.trustStore</code>
   <dd> This system property can be used to specify the location of an alternate
        truststore from which to obtain certificates for trusted entities.  If
        this property is not specified, then the
@@ -116,21 +116,21 @@ of the following system properties:
        applicable system property, if specified, is treated as a URL if it can 
        be parsed as such; if it cannot be parsed, it is treated as a file name.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.trustStoreType</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dt> <code>org.apache.river.discovery.x500.trustStoreType</code>
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is being used to specify the truststore location, then this
        system property can be used to specify the type of the truststore to
        load.  By default, the value returned by
        {@link java.security.KeyStore#getDefaultType} is used.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.trustStorePassword</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dt> <code>org.apache.river.discovery.x500.trustStorePassword</code>
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is being used to specify the truststore location, then this
        system property can be used to specify the password for accessing the
        contents of the truststore.  If it is not specified, then no password is
        used when accessing the truststore.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.ldapCertStores</code>
+  <dt> <code>org.apache.river.discovery.x500.ldapCertStores</code>
   <dd> This system property can be used to specify a list of LDAP-backed
        <code>CertStore</code>s to use for mapping received X.500 principals to
        corresponding X.509 certificates.  If set, it should contain a
@@ -141,11 +141,11 @@ of the following system properties:
        specify a port, a default port number of <code>389</code> is used.
        <p>
   <dt> <code>javax.net.ssl.trustStore</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is not set, then this system property can be used to specify
        the truststore from which to obtain certificates for trusted entities.
        If neither this property nor the
-       <code>com.sun.jini.discovery.x500.trustStore</code> property is
+       <code>org.apache.river.discovery.x500.trustStore</code> property is
        specified, then the <code>&lt;java-home&gt;/lib/security/cacerts</code>
        file is used.
        <p>
@@ -166,12 +166,12 @@ of the following system properties:
 <h2>Logging</h2>
 
 Both <code>Client</code> and <code>Server</code> use the
-{@link java.util.logging.Logger} named <code>com.sun.jini.discovery.x500</code>
+{@link java.util.logging.Logger} named <code>org.apache.river.discovery.x500</code>
 to log information at the following logging levels:
 <p>
 <table border="1" cellpadding="5"
        summary="Describes logging performed by the
-                com.sun.jini.discovery.x500.sha1withdsa provider classes at
+                org.apache.river.discovery.x500.sha1withdsa provider classes at
                 different logging levels">
   <tr> <th> Level   <th> Description
   <tr> <td> WARNING <td> Failure to initialize a certificate store

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Client.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Client.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Client.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Client.java Sat Jan 15 12:03:35 2011
@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withrsa;
+package org.apache.river.discovery.x500.sha1withrsa;
 
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastAnnouncementDecoder;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.MulticastRequestEncoder;
-import com.sun.jini.discovery.internal.X500Client;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastAnnouncementDecoder;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.MulticastRequestEncoder;
+import org.apache.river.discovery.internal.X500Client;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import net.jini.core.constraint.InvocationConstraints;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Constants.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Constants.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Constants.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Constants.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withrsa;
+package org.apache.river.discovery.x500.sha1withrsa;
 
 /**
  * Constants used by net.jini.discovery.x500.SHA1withRSA format providers.

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Server.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/Server.java Sat Jan 15 12:03:35 2011
@@ -16,15 +16,15 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.x500.sha1withrsa;
+package org.apache.river.discovery.x500.sha1withrsa;
 
-import com.sun.jini.discovery.ClientSubjectChecker;
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.discovery.DelayedMulticastRequestDecoder;
-import com.sun.jini.discovery.MulticastAnnouncement;
-import com.sun.jini.discovery.MulticastAnnouncementEncoder;
-import com.sun.jini.discovery.MulticastRequest;
-import com.sun.jini.discovery.internal.X500Server;
+import org.apache.river.discovery.ClientSubjectChecker;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.discovery.DelayedMulticastRequestDecoder;
+import org.apache.river.discovery.MulticastAnnouncement;
+import org.apache.river.discovery.MulticastAnnouncementEncoder;
+import org.apache.river.discovery.MulticastRequest;
+import org.apache.river.discovery.internal.X500Server;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import net.jini.core.constraint.InvocationConstraints;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/package.html
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/package.html?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/package.html (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/x500/sha1withrsa/package.html Sat Jan 15 12:03:35 2011
@@ -26,14 +26,14 @@
 Provides an implementation of the
 <code>net.jini.discovery.x500.SHA1withRSA</code> discovery format, specified in
 the <i>Jini Discovery and Join Specification</i>.  The {@link
-com.sun.jini.discovery.x500.sha1withrsa.Client} class implements the client
+org.apache.river.discovery.x500.sha1withrsa.Client} class implements the client
 side of the <code>net.jini.discovery.x500.SHA1withRSA</code> discovery format
 for the multicast request and multicast announcement discovery protocols, while
-the {@link com.sun.jini.discovery.x500.sha1withrsa.Server} class implements the
+the {@link org.apache.river.discovery.x500.sha1withrsa.Server} class implements the
 server side of the discovery format for those protocols.  Both classes are
 intended to be specified in a resource to configure the operation of the {@link
-com.sun.jini.discovery.Discovery} class, as described in the documentation for
-{@link com.sun.jini.discovery.Discovery#getProtocol2(ClassLoader)}.
+org.apache.river.discovery.Discovery} class, as described in the documentation for
+{@link org.apache.river.discovery.Discovery#getProtocol2(ClassLoader)}.
 
 <h2>Supported Constraints</h2>
 
@@ -106,7 +106,7 @@ Both <code>Client</code> and <code>Serve
 of the following system properties:
 <p>
 <dl>
-  <dt> <code>com.sun.jini.discovery.x500.trustStore</code>
+  <dt> <code>org.apache.river.discovery.x500.trustStore</code>
   <dd> This system property can be used to specify the location of an alternate
        truststore from which to obtain certificates for trusted entities.  If
        this property is not specified, then the
@@ -116,21 +116,21 @@ of the following system properties:
        applicable system property, if specified, is treated as a URL if it can 
        be parsed as such; if it cannot be parsed, it is treated as a file name.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.trustStoreType</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dt> <code>org.apache.river.discovery.x500.trustStoreType</code>
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is being used to specify the truststore location, then this
        system property can be used to specify the type of the truststore to
        load.  By default, the value returned by
        {@link java.security.KeyStore#getDefaultType} is used.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.trustStorePassword</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dt> <code>org.apache.river.discovery.x500.trustStorePassword</code>
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is being used to specify the truststore location, then this
        system property can be used to specify the password for accessing the
        contents of the truststore.  If it is not specified, then no password is
        used when accessing the truststore.
        <p>
-  <dt> <code>com.sun.jini.discovery.x500.ldapCertStores</code>
+  <dt> <code>org.apache.river.discovery.x500.ldapCertStores</code>
   <dd> This system property can be used to specify a list of LDAP-backed
        <code>CertStore</code>s to use for mapping received X.500 principals to
        corresponding X.509 certificates.  If set, it should contain a
@@ -141,11 +141,11 @@ of the following system properties:
        specify a port, a default port number of <code>389</code> is used.
        <p>
   <dt> <code>javax.net.ssl.trustStore</code>
-  <dd> If the <code>com.sun.jini.discovery.x500.trustStore</code> system
+  <dd> If the <code>org.apache.river.discovery.x500.trustStore</code> system
        property is not set, then this system property can be used to specify
        the truststore from which to obtain certificates for trusted entities.
        If neither this property nor the
-       <code>com.sun.jini.discovery.x500.trustStore</code> property is
+       <code>org.apache.river.discovery.x500.trustStore</code> property is
        specified, then the <code>&lt;java-home&gt;/lib/security/cacerts</code>
        file is used.
        <p>
@@ -166,12 +166,12 @@ of the following system properties:
 <h2>Logging</h2>
 
 Both <code>Client</code> and <code>Server</code> use the
-{@link java.util.logging.Logger} named <code>com.sun.jini.discovery.x500</code>
+{@link java.util.logging.Logger} named <code>org.apache.river.discovery.x500</code>
 to log information at the following logging levels:
 <p>
 <table border="1" cellpadding="5"
        summary="Describes logging performed by the
-                com.sun.jini.discovery.x500.sha1withrsa provider classes at
+                org.apache.river.discovery.x500.sha1withrsa provider classes at
                 different logging levels">
   <tr> <th> Level   <th> Description
   <tr> <td> WARNING <td> Failure to initialize a certificate store

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicConnManagerFactory.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicConnManagerFactory.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicConnManagerFactory.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicConnManagerFactory.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.connection;
+package org.apache.river.jeri.internal.connection;
 
 import net.jini.jeri.OutboundRequestIterator;
 import net.jini.jeri.connection.ConnectionEndpoint;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicServerConnManager.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicServerConnManager.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicServerConnManager.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/BasicServerConnManager.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.connection;
+package org.apache.river.jeri.internal.connection;
 
 import net.jini.jeri.RequestDispatcher;
 import net.jini.jeri.connection.ServerConnection;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManager.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManager.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManager.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManager.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.connection;
+package org.apache.river.jeri.internal.connection;
 
 import net.jini.jeri.OutboundRequestIterator;
 import net.jini.jeri.connection.ConnectionManager;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManagerFactory.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManagerFactory.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManagerFactory.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ConnManagerFactory.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.connection;
+package org.apache.river.jeri.internal.connection;
 
 import net.jini.jeri.connection.ConnectionEndpoint;
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ServerConnManager.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ServerConnManager.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ServerConnManager.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/connection/ServerConnManager.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.connection;
+package org.apache.river.jeri.internal.connection;
 
 import net.jini.jeri.RequestDispatcher;
 import net.jini.jeri.connection.ServerConnection;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ConnectionTimer.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ConnectionTimer.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ConnectionTimer.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ConnectionTimer.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 
 /**
  * Utility class for timing out connections.

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Header.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Header.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Header.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Header.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientConnection.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientConnection.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientConnection.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientConnection.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientManager.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientManager.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientManager.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientManager.java Sat Jan 15 12:03:35 2011
@@ -16,11 +16,11 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.collection.SoftCache;
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.collection.SoftCache;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.util.HashSet;
 import java.util.Set;
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientSocketFactory.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientSocketFactory.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientSocketFactory.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpClientSocketFactory.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.IOException;
 import java.net.Socket;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpParseException.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpParseException.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpParseException.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpParseException.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.IOException;
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerConnection.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerConnection.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerConnection.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerConnection.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.IOException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerManager.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerManager.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerManager.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpServerManager.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.Random;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpSettings.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpSettings.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageReader.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageReader.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.EOFException;
 import java.io.IOException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageWriter.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageWriter.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageWriter.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageWriter.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Request.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Request.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Request.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/Request.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ServerInfo.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ServerInfo.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ServerInfo.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/ServerInfo.java Sat Jan 15 12:03:35 2011
@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.jeri.internal.runtime.BASE64Encoder;
+import org.apache.river.jeri.internal.runtime.BASE64Encoder;
 import java.net.Authenticator;
 import java.net.InetAddress;
 import java.net.PasswordAuthentication;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/StartLine.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/StartLine.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/StartLine.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/StartLine.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedConnection.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedConnection.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedConnection.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedConnection.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 /**
  * Interface implemented by connections which can be timed out.

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedMap.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedMap.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedMap.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/TimedMap.java Sat Jan 15 12:03:35 2011
@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
-import com.sun.jini.thread.Executor;
+import org.apache.river.thread.Executor;
 import java.util.HashMap;
 import java.util.Map;
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ConnectionIO.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ConnectionIO.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ConnectionIO.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ConnectionIO.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/IOFuture.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/IOFuture.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/IOFuture.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/IOFuture.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
 import java.io.IOException;
 

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Mux.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Mux.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Mux.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Mux.java Sat Jan 15 12:03:35 2011
@@ -16,11 +16,11 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.jeri.internal.runtime.HexDumpEncoder;
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.jeri.internal.runtime.HexDumpEncoder;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxClient.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxClient.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxClient.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxClient.java Sat Jan 15 12:03:35 2011
@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.action.GetIntegerAction;
+import org.apache.river.action.GetIntegerAction;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -37,7 +37,7 @@ public class MuxClient extends Mux {
     /** initial inbound ration as client, default is 32768 */
     private static final int clientInitialInboundRation =
 	((Integer) AccessController.doPrivileged(new GetIntegerAction(
-	    "com.sun.jini.jeri.connection.mux.client.initialInboundRation",
+	    "org.apache.river.jeri.connection.mux.client.initialInboundRation",
 	    32768))).intValue();
 
     /**

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxServer.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxServer.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxServer.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/MuxServer.java Sat Jan 15 12:03:35 2011
@@ -16,11 +16,11 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.action.GetIntegerAction;
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.action.GetIntegerAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -47,7 +47,7 @@ public class MuxServer extends Mux {
     /** initial inbound ration as server, default is 32768 */
     private static final int serverInitialInboundRation =
 	((Integer) AccessController.doPrivileged(new GetIntegerAction(
-	    "com.sun.jini.jeri.connection.mux.server.initialInboundRation",
+	    "org.apache.river.jeri.connection.mux.server.initialInboundRation",
 	    32768))).intValue();
 
     /**

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ProtocolException.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ProtocolException.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ProtocolException.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/ProtocolException.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
 /**
  * ProtocolException is thrown inside the implementation of this package

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Session.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Session.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Session.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/Session.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/SocketChannelConnectionIO.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/SocketChannelConnectionIO.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/SocketChannelConnectionIO.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/SocketChannelConnectionIO.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.jeri.internal.runtime.SelectionManager;
-import com.sun.jini.logging.Levels;
+import org.apache.river.jeri.internal.runtime.SelectionManager;
+import org.apache.river.logging.Levels;
 import java.io.EOFException;
 import java.io.IOException;
 import java.nio.ByteBuffer;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/StreamConnectionIO.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/StreamConnectionIO.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/StreamConnectionIO.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/mux/StreamConnectionIO.java Sat Jan 15 12:03:35 2011
@@ -16,11 +16,11 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.mux;
+package org.apache.river.jeri.internal.mux;
 
-import com.sun.jini.logging.Levels;
-import com.sun.jini.thread.Executor;
-import com.sun.jini.thread.GetThreadPoolAction;
+import org.apache.river.logging.Levels;
+import org.apache.river.thread.Executor;
+import org.apache.river.thread.GetThreadPoolAction;
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/AbstractDgcClient.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/AbstractDgcClient.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/AbstractDgcClient.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/AbstractDgcClient.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
-import com.sun.jini.action.GetLongAction;
-import com.sun.jini.thread.NewThreadAction;
+import org.apache.river.action.GetLongAction;
+import org.apache.river.thread.NewThreadAction;
 import java.lang.ref.PhantomReference;
 import java.lang.ref.ReferenceQueue;
 import java.rmi.ConnectException;
@@ -89,19 +89,19 @@ abstract class AbstractDgcClient {
     /** lease duration to request (usually ignored by server) */
     private static final long leaseValue =		// default 10 minutes
 	((Long) AccessController.doPrivileged(new GetLongAction(
-	    "com.sun.jini.jeri.dgc.leaseValue", 600000)))
+	    "org.apache.river.jeri.dgc.leaseValue", 600000)))
 	    .longValue();
 
     /** maximum interval between retries of failed clean calls */
     private static final long cleanInterval =		// default 3 minutes
 	((Long) AccessController.doPrivileged(new GetLongAction(
-	    "com.sun.jini.jeri.dgc.cleanInterval", 180000)))
+	    "org.apache.river.jeri.dgc.cleanInterval", 180000)))
 	    .longValue();
 
     /** minimum lease duration that we bother to honor */
     private static final long minimumDuration =		// default 5 seconds
 	((Long) AccessController.doPrivileged(new GetLongAction(
-	    "com.sun.jini.jeri.dgc.minimumDuration", 5000)))
+	    "org.apache.river.jeri.dgc.minimumDuration", 5000)))
 	    .longValue();
 
     /** minimum retry count for dirty calls that fail */

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BASE64Encoder.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BASE64Encoder.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BASE64Encoder.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BASE64Encoder.java Sat Jan 15 12:03:35 2011
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
 import java.io.IOException;
 import java.io.OutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BasicExportTable.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BasicExportTable.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BasicExportTable.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/BasicExportTable.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
 import java.io.IOException;
 import java.io.InterruptedIOException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/CharacterEncoder.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/CharacterEncoder.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/CharacterEncoder.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/CharacterEncoder.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcClient.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcClient.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcClient.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcClient.java Sat Jan 15 12:03:35 2011
@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
-import com.sun.jini.logging.Levels;
+import org.apache.river.logging.Levels;
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.Proxy;
 import java.rmi.RemoteException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcServer.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcServer.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcServer.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/DgcServer.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/HexDumpEncoder.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/HexDumpEncoder.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/HexDumpEncoder.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/runtime/HexDumpEncoder.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.runtime;
+package org.apache.river.jeri.internal.runtime;
 
 import java.io.IOException;
 import java.io.OutputStream;
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Provider.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Provider.java Sat Jan 15 12:03:35 2011
@@ -16,10 +16,10 @@
  * limitations under the License.
  */
 
-package com.sun.jini.discovery.internal;
+package org.apache.river.discovery.internal;
 
-import com.sun.jini.discovery.DatagramBufferFactory;
-import com.sun.jini.logging.Levels;
+import org.apache.river.discovery.DatagramBufferFactory;
+import org.apache.river.logging.Levels;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -75,7 +75,7 @@ import net.jini.security.AuthenticationP
  */
 class X500Provider extends BaseProvider {
 
-    private static final String NAME = "com.sun.jini.discovery.x500";
+    private static final String NAME = "org.apache.river.discovery.x500";
     private static final String JSSE = "javax.net.ssl";
     private static final int INT_LEN = 4;
     private static final Pattern hostPortPattern =
@@ -128,21 +128,21 @@ class X500Provider extends BaseProvider 
      * time this method is called on this instance, a keystore containing trust
      * anchors for the certificate to return is loaded.  The location of the
      * file to load the keystore from can be specified (in order of precedence)
      * by the com.sun.jini.discovery.x500.trustStore and
      * javax.net.ssl.trustStore system properties; if no location is specified,
      * then the cacerts file in the lib/security subdirectory of the JDK
      * installation directory is used.  If specified, the location is treated as
      * a URL. If no protocol is specified in the URL or it is an unknown
      * protocol, then, the location is treated as a file name.
      * Depending on which system property is used to specify the keystore
      * location, the com.sun.jini.discovery.x500.trustStoreType and
      * com.sun.jini.discovery.x500.trustStorePassword or
      * javax.net.ssl.trustStoreType and javax.net.ssl.trustStorePassword system
      * properties can be used to specify the type of the keystore and the
      * password to use when loading it.  If no keystore type is specified, then
      * the type returned by KeyStore.getDefaultType() is used; if no password
      * is specified, then no password is used when loading the keystore.
      * Additionally, if the com.sun.jini.discovery.x500.ldapCertStores system
      * property is set, its value is interpreted as a comma-separated list of
      * "host[:port]" elements which are used to obtain references to LDAP-based
      * CertStore instances.
@@ -128,21 +128,21 @@ class X500Provider extends BaseProvider 
      * anchors for the certificate to return is loaded.  The location of the
      * file to load the keystore from can be specified (in order of precedence)
-     * by the com.sun.jini.discovery.x500.trustStore and
+     * by the org.apache.river.discovery.x500.trustStore and
      * javax.net.ssl.trustStore system properties; if no location is specified,
      * then the cacerts file in the lib/security subdirectory of the JDK
@@ -128,21 +128,21 @@ class X500Provider extends BaseProvider 
      * protocol, then, the location is treated as a file name.
      * Depending on which system property is used to specify the keystore
-     * location, the com.sun.jini.discovery.x500.trustStoreType and
-     * com.sun.jini.discovery.x500.trustStorePassword or
+     * location, the org.apache.river.discovery.x500.trustStoreType and
+     * org.apache.river.discovery.x500.trustStorePassword or
      * javax.net.ssl.trustStoreType and javax.net.ssl.trustStorePassword system
      * properties can be used to specify the type of the keystore and the
@@ -128,21 +128,21 @@ class X500Provider extends BaseProvider 
      * the type returned by KeyStore.getDefaultType() is used; if no password
      * is specified, then no password is used when loading the keystore.
-     * Additionally, if the com.sun.jini.discovery.x500.ldapCertStores system
+     * Additionally, if the org.apache.river.discovery.x500.ldapCertStores system
      * property is set, its value is interpreted as a comma-separated list of
      * "host[:port]" elements which are used to obtain references to LDAP-based

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Server.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/discovery/internal/X500Server.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================
--- incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpSettings.java (original)
+++ incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/HttpSettings.java Sat Jan 15 12:03:35 2011
@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package com.sun.jini.jeri.internal.http;
+package org.apache.river.jeri.internal.http;
 
 import java.lang.ref.SoftReference;
 import java.util.ArrayList;
@@ -105,13 +105,13 @@ public class HttpSettings {
     }
 
     /**
      * Returns com.sun.jini.jeri.http[s].responseAckTimeout system
      * property value if set; otherwise returns 15000.
      */
     public long getResponseAckTimeout() {
 	String str = props.getProperty(ssl ?
-	    "com.sun.jini.jeri.https.responseAckTimeout" :
-	    "com.sun.jini.jeri.http.responseAckTimeout");
+	    "org.apache.river.jeri.https.responseAckTimeout" :
+	    "org.apache.river.jeri.http.responseAckTimeout");
 	if (str != null) {
 	    try { return Long.parseLong(str); } catch (Exception ex) {}
 	}
@@ -119,13 +119,13 @@ public class HttpSettings {
     }
     
     /**
-     * Returns com.sun.jini.jeri.http[s].idleConnectionTimeout
+     * Returns org.apache.river.jeri.http[s].idleConnectionTimeout
      * system property value if set; otherwise returns 15000.
      */
     public long getConnectionTimeout() {
 	String str = props.getProperty(ssl ?
-	    "com.sun.jini.jeri.https.idleConnectionTimeout" :
-	    "com.sun.jini.jeri.http.idleConnectionTimeout");
+	    "org.apache.river.jeri.https.idleConnectionTimeout" :
+	    "org.apache.river.jeri.http.idleConnectionTimeout");
 	if (str != null) {
 	    try { return Long.parseLong(str); } catch (Exception ex) {}
 	}
@@ -133,14 +133,14 @@ public class HttpSettings {
     }
 
     /**
-     * Returns com.sun.jini.jeri.http[s].idleServerConnectionTimeout
+     * Returns org.apache.river.jeri.http[s].idleServerConnectionTimeout
      * system property value if set; otherwise returns getConnectionTimeout()
      * plus 30000 (if ssl) or 10000 (if not ssl).
      */
     public long getServerConnectionTimeout() {
 	String str = props.getProperty(ssl ?
-	    "com.sun.jini.jeri.https.idleServerConnectionTimeout" :
-	    "com.sun.jini.jeri.http.idleServerConnectionTimeout");
+	    "org.apache.river.jeri.https.idleServerConnectionTimeout" :
+	    "org.apache.river.jeri.http.idleServerConnectionTimeout");
 	if (str != null) {
 	    try { return Long.parseLong(str); } catch (Exception ex) {}
 	}
@@ -148,7 +148,7 @@ public class HttpSettings {
     }
 
     /**
-     * Returns com.sun.jini.jeri.http.disableProxyPersistentConnections
+     * Returns org.apache.river.jeri.http.disableProxyPersistentConnections
      * system property as boolean value if set and not ssl; otherwise returns
      * false.
      */
@@ -156,30 +156,30 @@ public class HttpSettings {
 	return ssl ?
 	    false :
 	    Boolean.valueOf(props.getProperty(
-		"com.sun.jini.jeri.http.disableProxyPersistentConnections")).
+		"org.apache.river.jeri.http.disableProxyPersistentConnections")).
 								booleanValue();
     }
 
     /**
      * Returns com.sun.jini.jeri.http.pingProxyConnections system
      * property as boolean value if set; otherwise returns false.
      */
     public boolean getPingProxyConnections() {
-	String key = ssl ? "com.sun.jini.jeri.https.pingProxyConnections"
-	                 : "com.sun.jini.jeri.http.pingProxyConnections";
+	String key = ssl ? "org.apache.river.jeri.https.pingProxyConnections"
+	                 : "org.apache.river.jeri.http.pingProxyConnections";
 	String prop = props.getProperty(key);
 	boolean ping = Boolean.valueOf(prop).booleanValue();
 	return ping;
     }
 
     /**
-     * Returns com.sun.jini.jeri.http.pingProxyConnectionTimeout
+     * Returns org.apache.river.jeri.http.pingProxyConnectionTimeout
      * system property as long value if set; otherwise returns
      * Long.MAX_VALUE (essentially, never timeout).
      */
     public long getPingProxyConnectionTimeout() {
-	String key = ssl? "com.sun.jini.jeri.https.pingProxyConnectionTimeout"
-	                : "com.sun.jini.jeri.http.pingProxyConnectionTimeout";
+	String key = ssl? "org.apache.river.jeri.https.pingProxyConnectionTimeout"
+	                : "org.apache.river.jeri.http.pingProxyConnectionTimeout";
 	String prop = props.getProperty(key);
 	try {
 	    long timeout = Long.valueOf(prop).longValue();
@@ -105,13 +105,13 @@ public class HttpSettings {
 
     /**
-     * Returns com.sun.jini.jeri.http[s].responseAckTimeout system
+     * Returns org.apache.river.jeri.http[s].responseAckTimeout system
      * property value if set; otherwise returns 15000.
      */
@@ -156,30 +156,30 @@ public class HttpSettings {
 
     /**
-     * Returns com.sun.jini.jeri.http.pingProxyConnections system
+     * Returns org.apache.river.jeri.http.pingProxyConnections system
      * property as boolean value if set; otherwise returns false.
      */

Modified: incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageReader.java
URL: http://svn.apache.org/viewvc/incubator/river/jtsk/skunk/modules/river-platform/src/main/java/org/apache/river/jeri/internal/http/MessageReader.java?rev=1059307&r1=1059306&r2=1059307&view=diff
==============================================================================